@@ -7,7 +7,7 @@ import numpy as np
 import pandas as pd
 
 from cmdstanpy.cmdstan_args import Method, OptimizeArgs
-from cmdstanpy.utils import BaseType, get_logger, scan_optimize_csv
+from cmdstanpy.utils import get_logger, scan_optimize_csv
 
 from .metadata import InferenceMetadata
 from .runset import RunSet
@@ -189,14 +189,15 @@ class CmdStanMLE:
         --------
         CmdStanMLE.stan_variables
         CmdStanMCMC.stan_variable
+        CmdStanPathfinder.stan_variable
         CmdStanVB.stan_variable
         CmdStanGQ.stan_variable
+        CmdStanLaplace.stan_variable
         """
-        if var not in self._metadata.stan_vars_dims:
+        if var not in self._metadata.stan_vars:
             raise ValueError(
                 f'Unknown variable name: {var}\n'
-                'Available variables are '
-                + ", ".join(self._metadata.stan_vars_dims)
+                'Available variables are ' + ", ".join(self._metadata.stan_vars)
             )
         if warn and inc_iterations and not self._save_iterations:
             get_logger().warning(
@@ -207,36 +208,31 @@ class CmdStanMLE:
             get_logger().warning(
                 'Invalid estimate, optimization failed to converge.'
             )
-
-        col_idxs = list(self._metadata.stan_vars_cols[var])
         if inc_iterations and self._save_iterations:
-            num_rows = self._all_iters.shape[0]
+            data = self._all_iters
         else:
-            num_rows = 1
+            data = self._mle
 
-        if len(col_idxs) > 1:  # container var
-            dims = (num_rows,) + self._metadata.stan_vars_dims[var]
-            # pylint: disable=redundant-keyword-arg
-            if num_rows > 1:
-                result = self._all_iters[:, col_idxs]
-            else:
-                result = self._mle[col_idxs]
-                dims = dims[1:]
-
-            if self._metadata.stan_vars_types[var] == BaseType.COMPLEX:
-                result = result[..., ::2] + 1j * result[..., 1::2]
-                dims = dims[:-1]
-
-            result = result.reshape(dims, order='F')
-
-            return result
-
-        else:  # scalar var
-            col_idx = col_idxs[0]
-            if num_rows > 1:
-                return self._all_iters[:, col_idx]
-            else:
-                return float(self._mle[col_idx])
+        try:
+            out: np.ndarray = self._metadata.stan_vars[var].extract_reshape(
+                data
+            )
+            # TODO(2.0) remove
+            if out.shape == () or out.shape == (1,):
+                get_logger().warning(
+                    "The default behavior of CmdStanMLE.stan_variable() "
+                    "will change in a future release to always return a "
+                    "numpy.ndarray, even for scalar variables."
+                )
+                return out.item()  # type: ignore
+            return out
+        except KeyError:
+            # pylint: disable=raise-missing-from
+            raise ValueError(
+                f'Unknown variable name: {var}\n'
+                'Available variables are '
+                + ", ".join(self._metadata.stan_vars.keys())
+            )
 
     def stan_variables(
         self, inc_iterations: bool = False
@@ -255,15 +251,17 @@ class CmdStanMLE:
         --------
         CmdStanMLE.stan_variable
         CmdStanMCMC.stan_variables
+        CmdStanPathfinder.stan_variables
         CmdStanVB.stan_variables
         CmdStanGQ.stan_variables
+        CmdStanLaplace.stan_variables
         """
         if not self.runset._check_retcodes():
             get_logger().warning(
                 'Invalid estimate, optimization failed to converge.'
             )
         result = {}
-        for name in self._metadata.stan_vars_dims.keys():
+        for name in self._metadata.stan_vars:
             result[name] = self.stan_variable(
                 name, inc_iterations=inc_iterations, warn=False
             )
